==> 13.9.tar.gz: t2codelib/src/main/java/net/t2code/t2codelib/SPIGOT/system/config/config/ConfigCreate.java <==
package net.t2code.t2codelib.SPIGOT.system.config.config;

import net.t2code.t2codelib.SPIGOT.api.messages.T2Csend;
import net.t2code.t2codelib.SPIGOT.api.yaml.T2Cconfig;
import net.t2code.t2codelib.SPIGOT.system.T2CodeLibMain;
import net.t2code.t2codelib.Util;
import org.bukkit.configuration.file.YamlConfiguration;

import java.io.File;
import java.io.IOException;


public class ConfigCreate {

    public static void configCreate() {
        long long_ = System.currentTimeMillis();
        if (new File(T2CodeLibMain.getPath(), "config.yml").exists()){
            if (T2CodeLibMain.getPlugin().getConfig().getBoolean("Plugin.Debug")) T2Csend.console(Util.getPrefix() + " §5DEBUG: §6" +  " §4config.yml are created / updated...");
        } else T2Csend.console(Util.getPrefix() + " §4config.yml are created...");


        File config = new File(T2CodeLibMain.getPath(), "config.yml");
        YamlConfiguration yamlConfiguration = YamlConfiguration.loadConfiguration(config);

        T2Cconfig.set("Plugin.UpdateCheck.OnJoin", true, yamlConfiguration);
        T2Cconfig.set("Plugin.UpdateCheck.TimeInterval", 60, yamlConfiguration);
        T2Cconfig.set("Plugin.UpdateCheck.SeePreReleaseUpdates", true, yamlConfiguration);
        T2Cconfig.set("Plugin.language", "english", yamlConfiguration);

        T2Cconfig.set("BungeeCord.Enable", false, yamlConfiguration);
        T2Cconfig.set("Player.Inventories.CloseByServerStop", true, yamlConfiguration);

        try {
            yamlConfiguration.save(config);
        } catch (IOException e) {
            e.printStackTrace();
        }

        T2Csend.console(Util.getPrefix() + " §2config.yml were successfully created / updated." + " §7- §e" + (System.currentTimeMillis() - long_) + "ms");
    }
}

==> 14.2.tar.gz: t2codelib/src/main/java/net/t2code/t2codelib/SPIGOT/system/config/config/ConfigCreate.java <==
package net.t2code.t2codelib.SPIGOT.system.config.config;

import net.t2code.t2codelib.SPIGOT.api.messages.T2Csend;
import net.t2code.t2codelib.SPIGOT.api.yaml.T2Cconfig;
import net.t2code.t2codelib.SPIGOT.system.T2CodeLibMain;
import net.t2code.t2codelib.Util;
import org.bukkit.configuration.file.YamlConfiguration;

import java.io.File;
import java.io.IOException;


public class ConfigCreate {

    public static void configCreate() {
        long long_ = System.currentTimeMillis();
        if (new File(T2CodeLibMain.getPath(), "config.yml").exists()){
            if (T2CodeLibMain.getPlugin().getConfig().getBoolean("Plugin.Debug")) T2Csend.console(Util.getPrefix() + " §5DEBUG: §6" +  " §4config.yml are created / updated...");
        } else T2Csend.console(Util.getPrefix() + " §4config.yml are created...");


        File config = new File(T2CodeLibMain.getPath(), "config.yml");
        YamlConfiguration yamlConfiguration = YamlConfiguration.loadConfiguration(config);

        T2Cconfig.set("Plugin.UpdateCheck.OnJoin", true, yamlConfiguration);
        T2Cconfig.set("Plugin.UpdateCheck.TimeInterval", 60, yamlConfiguration);
        T2Cconfig.set("Plugin.UpdateCheck.SeePreReleaseUpdates", true, yamlConfiguration);
        T2Cconfig.set("Plugin.language", "english", yamlConfiguration);

        T2Cconfig.set("BungeeCord.Enable", T2CodeLibMain.getIsBungee(), yamlConfiguration);
        T2Cconfig.set("Player.Inventories.CloseByServerStop", true, yamlConfiguration);

        try {
            yamlConfiguration.save(config);
        } catch (IOException e) {
            e.printStackTrace();
        }

        T2Csend.console(Util.getPrefix() + " §2config.yml were successfully created / updated." + " §7- §e" + (System.currentTimeMillis() - long_) + "ms");
    }
}
